@@ -108,8 +108,8 @@ class LightgbmAlgorithm(BaseAlgorithm):
 lgbm_bin_params = {
     "objective": ["binary"],
     "metric": ["binary_logloss", "auc"],
-    "num_leaves": [2, 4, 8, 16, 32, 64, 128, 256, 512, 1024],
-    "learning_rate": [0.05, 0.1, 0.15, 0.2, 0.25, 0.3],
+    "num_leaves": [32, 64, 128, 256, 512],
+    "learning_rate": [0.01, 0.025, 0.05, 0.075, 0.1],
     "feature_fraction": [0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "bagging_fraction": [0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0],
     "bagging_freq": [0, 1, 2, 3, 4, 5],
@@ -117,8 +117,9 @@ lgbm_bin_params = {
 
 
 additional = {
-    "trees_in_step": 50,
+    "trees_in_step": 10,
     "train_cant_improve_limit": 5,
+    "min_steps": 5,
     "max_steps": 500,
     "max_rows_limit": None,
     "max_cols_limit": None,
